function y = getkey(cfile, gfile)
% Usage:
% key = getkey('conf.cfc', 'conf.cfg');
% Files have to be present in current folder.
% Extracted key is written to 'key.bin'

% read crypted input file (conf.cfc)
fid=fopen(cfile, 'r');
[cconf csize]=fread(fid);
fclose(fid);

% read template (conf.cfg)
fid=fopen(gfile, 'r');
[gconf gsize]=fread(fid);
fclose(fid);

% get size of smallest file
fsize=min([csize gsize]);

% crop input files to multiples of 289
ccount=floor(fsize/289);
cconf=(cconf(1:ccount*289));
gconf=(gconf(1:ccount*289));

% reshape to 289*X matrix
cconf=reshape(cconf, 289, ccount);
gconf=reshape(gconf, 289, ccount);

% xor
ckey=bitxor(cconf,gconf);

% find most common value for each row
key=NaN(289,1);
for k=1:289
  % unique values
  a=unique(ckey(k,:));
  % histogram count
  b=histc(ckey(k,:), a);
  % index of most common element
  [c d]=max(b);
  key(k)=a(d);
end

% write key to file
fid=fopen('key.bin', 'w');
fwrite(fid, key);
fclose(fid);

% return key
y=key;

end
